@@ -147,7 +147,7 @@ class UploadVideo:
         caption: str,
         thumbnail: str = None,
         usertags: list = [],
-        configure_timeout: str = 3,
+        configure_timeout: int = 3,
         configure_handler=None,
         configure_exception=None,
         to_story: bool = False,
@@ -243,7 +243,7 @@ class UploadVideo:
         caption: str,
         thumbnail: str = None,
         usertags: list = [],
-        configure_timeout: str = 3,
+        configure_timeout: int = 3,
         links: list = []
     ) -> dict:
         """Upload video to feed
